@@ -5,7 +5,7 @@ module.exports = function () {
     var line = '';
     var stream = through(write, flush);
     return stream;
-    
+
     function write (buf) {
         for (var i = 0; i < buf.length; i++) {
             var c = typeof buf === 'string'
@@ -16,13 +16,12 @@ module.exports = function () {
             else line += c;
         }
     }
-    
+
     function flush () {
         if (fs.writeSync && /^win/.test(process.platform)) {
             try { fs.writeSync(1, line + '\n'); }
             catch (e) { stream.emit('error', e) }
-        }
-        else {
+        } else {
             try { console.log(line) }
             catch (e) { stream.emit('error', e) }
         }
