@@ -1,9 +1,11 @@
 var test = require('../../');
 
 test('double end', function (t) {
+    function doEnd() {
+        t.end();
+    }
+
     t.equal(1 + 1, 2);
     t.end();
-    setTimeout(function () {
-        t.end();
-    }, 5);
+    setTimeout(doEnd, 5);
 });
