@@ -2,17 +2,22 @@ var tape = require('../');
 var tap = require('tap');
 var concat = require('concat-stream');
 
+var stripFullStack = require('./common').stripFullStack;
+
 tap.test('timeoutAfter test', function (tt) {
     tt.plan(1);
-    
+
     var test = tape.createHarness();
     var tc = function (rows) {
-        tt.same(rows.toString('utf8'), [
+        tt.same(stripFullStack(rows.toString('utf8')), [
             'TAP version 13',
             '# timeoutAfter',
             'not ok 1 test timed out after 1ms',
             '  ---',
             '    operator: fail',
+            '    stack: |-',
+            '      Error: test timed out after 1ms',
+            '          [... stack stripped ...]',
             '  ...',
             '',
             '1..1',
@@ -21,9 +26,9 @@ tap.test('timeoutAfter test', function (tt) {
             '# fail  1'
         ].join('\n') + '\n');
     };
-    
+
     test.createStream().pipe(concat(tc));
-    
+
     test('timeoutAfter', function (t) {
         t.plan(1);
         t.timeoutAfter(1);
