@@ -2,13 +2,15 @@ var tape = require('../');
 var tap = require('tap');
 var concat = require('concat-stream');
 
+var stripFullStack = require('./common').stripFullStack;
+
 tap.test('array test', function (tt) {
     tt.plan(1);
-    
+
     var test = tape.createHarness();
     test.createStream().pipe(concat(function (body) {
         tt.equal(
-            body.toString('utf8'),
+            stripFullStack(body.toString('utf8')),
             'TAP version 13\n'
             + '# undef\n'
             + 'not ok 1 should be equivalent\n'
@@ -18,6 +20,12 @@ tap.test('array test', function (tt) {
             + '      { beep: undefined }\n'
             + '    actual: |-\n'
             + '      {}\n'
+            + '    at: Test.<anonymous> ($TEST/undef.js:$LINE:$COL)\n'
+            + '    stack: |-\n'
+            + '      Error: should be equivalent\n'
+            + '          [... stack stripped ...]\n'
+            + '          at Test.<anonymous> ($TEST/undef.js:$LINE:$COL)\n'
+            + '          [... stack stripped ...]\n'
             + '  ...\n'
             + '\n'
             + '1..1\n'
@@ -26,7 +34,7 @@ tap.test('array test', function (tt) {
             + '# fail  1\n'
         );
     }));
-    
+
     test('undef', function (t) {
         t.plan(1);
         t.deepEqual({}, { beep: undefined });
